# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MessageCodiAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'concept': 'str',
        'due_date': 'datetime',
        'id': 'str',
        'metadata': 'str',
        'operation_date': 'datetime',
        'order_id': 'str',
        'payment_type': 'str',
        'reference': 'str',
        'sales_point_id': 'str',
        'status': 'str',
        'transaction_id': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'concept': 'concept',
        'due_date': 'due_date',
        'id': 'id',
        'metadata': 'metadata',
        'operation_date': 'operation_date',
        'order_id': 'order_id',
        'payment_type': 'payment_type',
        'reference': 'reference',
        'sales_point_id': 'sales_point_id',
        'status': 'status',
        'transaction_id': 'transaction_id'
    }

    def __init__(self, amount=None, concept=None, due_date=None, id=None, metadata=None, operation_date=None, order_id=None, payment_type=None, reference=None, sales_point_id=None, status=None, transaction_id=None):  # noqa: E501
        """MessageCodiAction - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._concept = None
        self._due_date = None
        self._id = None
        self._metadata = None
        self._operation_date = None
        self._order_id = None
        self._payment_type = None
        self._reference = None
        self._sales_point_id = None
        self._status = None
        self._transaction_id = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if concept is not None:
            self.concept = concept
        if due_date is not None:
            self.due_date = due_date
        if id is not None:
            self.id = id
        if metadata is not None:
            self.metadata = metadata
        if operation_date is not None:
            self.operation_date = operation_date
        if order_id is not None:
            self.order_id = order_id
        if payment_type is not None:
            self.payment_type = payment_type
        if reference is not None:
            self.reference = reference
        if sales_point_id is not None:
            self.sales_point_id = sales_point_id
        if status is not None:
            self.status = status
        if transaction_id is not None:
            self.transaction_id = transaction_id

    @property
    def amount(self):
        """Gets the amount of this MessageCodiAction.  # noqa: E501

        Es el monto de la operación de pago.  # noqa: E501

        :return: The amount of this MessageCodiAction.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this MessageCodiAction.

        Es el monto de la operación de pago.  # noqa: E501

        :param amount: The amount of this MessageCodiAction.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def concept(self):
        """Gets the concept of this MessageCodiAction.  # noqa: E501

        Es el concepto de la transacción.  # noqa: E501

        :return: The concept of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._concept

    @concept.setter
    def concept(self, concept):
        """Sets the concept of this MessageCodiAction.

        Es el concepto de la transacción.  # noqa: E501

        :param concept: The concept of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._concept = concept

    @property
    def due_date(self):
        """Gets the due_date of this MessageCodiAction.  # noqa: E501

        Es la fecha de expiración de la operación.  # noqa: E501

        :return: The due_date of this MessageCodiAction.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this MessageCodiAction.

        Es la fecha de expiración de la operación.  # noqa: E501

        :param due_date: The due_date of this MessageCodiAction.  # noqa: E501
        :type: datetime
        """

        self._due_date = due_date

    @property
    def id(self):
        """Gets the id of this MessageCodiAction.  # noqa: E501

        Es el UUID de la operación.  # noqa: E501

        :return: The id of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MessageCodiAction.

        Es el UUID de la operación.  # noqa: E501

        :param id: The id of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def metadata(self):
        """Gets the metadata of this MessageCodiAction.  # noqa: E501

        Es el campo Metadata asociado a la petición de pago. Es información que indica guardar la petición.  # noqa: E501

        :return: The metadata of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this MessageCodiAction.

        Es el campo Metadata asociado a la petición de pago. Es información que indica guardar la petición.  # noqa: E501

        :param metadata: The metadata of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._metadata = metadata

    @property
    def operation_date(self):
        """Gets the operation_date of this MessageCodiAction.  # noqa: E501

        Es la fecha de la operación.  # noqa: E501

        :return: The operation_date of this MessageCodiAction.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date

    @operation_date.setter
    def operation_date(self, operation_date):
        """Sets the operation_date of this MessageCodiAction.

        Es la fecha de la operación.  # noqa: E501

        :param operation_date: The operation_date of this MessageCodiAction.  # noqa: E501
        :type: datetime
        """

        self._operation_date = operation_date

    @property
    def order_id(self):
        """Gets the order_id of this MessageCodiAction.  # noqa: E501

        Es el identificador de la petición.  # noqa: E501

        :return: The order_id of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this MessageCodiAction.

        Es el identificador de la petición.  # noqa: E501

        :param order_id: The order_id of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def payment_type(self):
        """Gets the payment_type of this MessageCodiAction.  # noqa: E501

        Es el tipo de pago.  # noqa: E501

        :return: The payment_type of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """Sets the payment_type of this MessageCodiAction.

        Es el tipo de pago.  # noqa: E501

        :param payment_type: The payment_type of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._payment_type = payment_type

    @property
    def reference(self):
        """Gets the reference of this MessageCodiAction.  # noqa: E501

        Es el número de referencia.  # noqa: E501

        :return: The reference of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this MessageCodiAction.

        Es el número de referencia.  # noqa: E501

        :param reference: The reference of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def sales_point_id(self):
        """Gets the sales_point_id of this MessageCodiAction.  # noqa: E501

        Identidicador del punto de venta a la que pertenece la petición de pago.  # noqa: E501

        :return: The sales_point_id of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._sales_point_id

    @sales_point_id.setter
    def sales_point_id(self, sales_point_id):
        """Sets the sales_point_id of this MessageCodiAction.

        Identidicador del punto de venta a la que pertenece la petición de pago.  # noqa: E501

        :param sales_point_id: The sales_point_id of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._sales_point_id = sales_point_id

    @property
    def status(self):
        """Gets the status of this MessageCodiAction.  # noqa: E501

        Es el estado (estatus) de la operación de pago.  # noqa: E501

        :return: The status of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this MessageCodiAction.

        Es el estado (estatus) de la operación de pago.  # noqa: E501

        :param status: The status of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def transaction_id(self):
        """Gets the transaction_id of this MessageCodiAction.  # noqa: E501

        Es el identificador de la transacción.  # noqa: E501

        :return: The transaction_id of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this MessageCodiAction.

        Es el identificador de la transacción.  # noqa: E501

        :param transaction_id: The transaction_id of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageCodiAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageCodiAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
