# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AmountRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_limit': 'float',
        'cancel_return_url': 'str',
        'currency_code': 'str',
        'previous_amount_limit': 'float',
        'return_url': 'str'
    }

    attribute_map = {
        'amount_limit': 'amount_limit',
        'cancel_return_url': 'cancel_return_url',
        'currency_code': 'currency_code',
        'previous_amount_limit': 'previous_amount_limit',
        'return_url': 'return_url'
    }

    def __init__(self, amount_limit=None, cancel_return_url=None, currency_code=None, previous_amount_limit=None, return_url=None):  # noqa: E501
        """AmountRequest - a model defined in Swagger"""  # noqa: E501
        self._amount_limit = None
        self._cancel_return_url = None
        self._currency_code = None
        self._previous_amount_limit = None
        self._return_url = None
        self.discriminator = None
        self.amount_limit = amount_limit
        self.cancel_return_url = cancel_return_url
        self.currency_code = currency_code
        self.previous_amount_limit = previous_amount_limit
        self.return_url = return_url

    @property
    def amount_limit(self):
        """Gets the amount_limit of this AmountRequest.  # noqa: E501

        Es el nuevo monto límite que reemplazará al actual, un monto de 0.0 implica que no hay límite.  # noqa: E501

        :return: The amount_limit of this AmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._amount_limit

    @amount_limit.setter
    def amount_limit(self, amount_limit):
        """Sets the amount_limit of this AmountRequest.

        Es el nuevo monto límite que reemplazará al actual, un monto de 0.0 implica que no hay límite.  # noqa: E501

        :param amount_limit: The amount_limit of this AmountRequest.  # noqa: E501
        :type: float
        """
        if amount_limit is None:
            raise ValueError("Invalid value for `amount_limit`, must not be `None`")  # noqa: E501

        self._amount_limit = amount_limit

    @property
    def cancel_return_url(self):
        """Gets the cancel_return_url of this AmountRequest.  # noqa: E501

        Es la dirección URL a la que se redirigirá en caso de que el cliente cancele el registro. Se valida hasta 512 caracteres.  # noqa: E501

        :return: The cancel_return_url of this AmountRequest.  # noqa: E501
        :rtype: str
        """
        return self._cancel_return_url

    @cancel_return_url.setter
    def cancel_return_url(self, cancel_return_url):
        """Sets the cancel_return_url of this AmountRequest.

        Es la dirección URL a la que se redirigirá en caso de que el cliente cancele el registro. Se valida hasta 512 caracteres.  # noqa: E501

        :param cancel_return_url: The cancel_return_url of this AmountRequest.  # noqa: E501
        :type: str
        """
        if cancel_return_url is None:
            raise ValueError("Invalid value for `cancel_return_url`, must not be `None`")  # noqa: E501

        self._cancel_return_url = cancel_return_url

    @property
    def currency_code(self):
        """Gets the currency_code of this AmountRequest.  # noqa: E501

        Es el código de divisa de la cuenta. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :return: The currency_code of this AmountRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this AmountRequest.

        Es el código de divisa de la cuenta. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :param currency_code: The currency_code of this AmountRequest.  # noqa: E501
        :type: str
        """
        if currency_code is None:
            raise ValueError("Invalid value for `currency_code`, must not be `None`")  # noqa: E501

        self._currency_code = currency_code

    @property
    def previous_amount_limit(self):
        """Gets the previous_amount_limit of this AmountRequest.  # noqa: E501

        Es el monto límite registrado actualmente, un monto de 0.0 implica que no hay límite.  # noqa: E501

        :return: The previous_amount_limit of this AmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._previous_amount_limit

    @previous_amount_limit.setter
    def previous_amount_limit(self, previous_amount_limit):
        """Sets the previous_amount_limit of this AmountRequest.

        Es el monto límite registrado actualmente, un monto de 0.0 implica que no hay límite.  # noqa: E501

        :param previous_amount_limit: The previous_amount_limit of this AmountRequest.  # noqa: E501
        :type: float
        """
        if previous_amount_limit is None:
            raise ValueError("Invalid value for `previous_amount_limit`, must not be `None`")  # noqa: E501

        self._previous_amount_limit = previous_amount_limit

    @property
    def return_url(self):
        """Gets the return_url of this AmountRequest.  # noqa: E501

        Es la dirección URL a la que se redirigirá en caso de éxito. Se valida hasta 512 caracteres.  # noqa: E501

        :return: The return_url of this AmountRequest.  # noqa: E501
        :rtype: str
        """
        return self._return_url

    @return_url.setter
    def return_url(self, return_url):
        """Sets the return_url of this AmountRequest.

        Es la dirección URL a la que se redirigirá en caso de éxito. Se valida hasta 512 caracteres.  # noqa: E501

        :param return_url: The return_url of this AmountRequest.  # noqa: E501
        :type: str
        """
        if return_url is None:
            raise ValueError("Invalid value for `return_url`, must not be `None`")  # noqa: E501

        self._return_url = return_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AmountRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AmountRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
