# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MessageInstitution(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company_name': 'str',
        'key': 'str',
        'name': 'str',
        'rfc': 'str'
    }

    attribute_map = {
        'company_name': 'company_name',
        'key': 'key',
        'name': 'name',
        'rfc': 'rfc'
    }

    def __init__(self, company_name=None, key=None, name=None, rfc=None):  # noqa: E501
        """MessageInstitution - a model defined in Swagger"""  # noqa: E501
        self._company_name = None
        self._key = None
        self._name = None
        self._rfc = None
        self.discriminator = None
        if company_name is not None:
            self.company_name = company_name
        if key is not None:
            self.key = key
        if name is not None:
            self.name = name
        if rfc is not None:
            self.rfc = rfc

    @property
    def company_name(self):
        """Gets the company_name of this MessageInstitution.  # noqa: E501

        Es el nombre de la institución bancaria registrada ante el Servicio de Administración Tributaria (SAT).  # noqa: E501

        :return: The company_name of this MessageInstitution.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this MessageInstitution.

        Es el nombre de la institución bancaria registrada ante el Servicio de Administración Tributaria (SAT).  # noqa: E501

        :param company_name: The company_name of this MessageInstitution.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def key(self):
        """Gets the key of this MessageInstitution.  # noqa: E501

        Es la clave de la institución bancaria.  # noqa: E501

        :return: The key of this MessageInstitution.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this MessageInstitution.

        Es la clave de la institución bancaria.  # noqa: E501

        :param key: The key of this MessageInstitution.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def name(self):
        """Gets the name of this MessageInstitution.  # noqa: E501

        Es el nombre de la institución bancaria.  # noqa: E501

        :return: The name of this MessageInstitution.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MessageInstitution.

        Es el nombre de la institución bancaria.  # noqa: E501

        :param name: The name of this MessageInstitution.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def rfc(self):
        """Gets the rfc of this MessageInstitution.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) de la institución.  # noqa: E501

        :return: The rfc of this MessageInstitution.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this MessageInstitution.

        Es el Registro Federal de Contribuyentes (RFC) de la institución.  # noqa: E501

        :param rfc: The rfc of this MessageInstitution.  # noqa: E501
        :type: str
        """

        self._rfc = rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageInstitution, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageInstitution):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
